@@ -94,7 +94,7 @@ RT_MARK = ST_NO_RESULT - 1
 
 RT_RESULTS = (RT_RESPONSE, RT_EXCEPTION)
 
-RECONNECT_TIMEOUT = 3 #wait reconnect time, zero will disable reconnect wait
+RECONNECT_TIMEOUT = 0 #wait reconnect time, zero will disable reconnect wait
 HEARTBEAT_TIME = 60 #heartbeat, if disconnect time > (HEARTBEAT_TIME + RECONNECT_TIMEOUT), connect lost
 CALL_TIMEORUT = 240
 ZIP_LENGTH = 1024 * 2 #if argkw > Nk, use zlib to compress
@@ -690,11 +690,12 @@ class RpcService(object):
     def heartbeat(self):
         beat = RT_HEARTBEAT
         btime = HEARTBEAT_TIME
+        check_times = HEARTBEAT_TIME * max(3, RECONNECT_TIMEOUT)
         try:
             while not self.stoped:
                 self.send(beat)
                 sleep(btime)
-                if self._heart_time + btime + 10 < time.time():
+                if (self._heart_time + check_times) < time.time():
                     printf('heartbeat timeout!!!!!!!!')
                     self.sock_error = True
                     break
