@@ -10,6 +10,7 @@ if sys.platform.startswith('linux'):
     endpoint = 'test.sock'
 else:
     endpoint = ('127.0.0.1', 18081)
+#    endpoint = ('10.96.130.150', 18011)
 server_id = 'server'
 master_id = 'master'
 
@@ -57,7 +58,7 @@ def benchmark2():
     proxys = [make_proxy(i) for i in xrange(proxy_count)]
 
     def test_echo(proxy):
-        rs = proxy.echo(proxy.name)
+        rs = proxy.echo(proxy.name)#, _no_result=1)
         assert rs == proxy.name, 'echo error'
         index[0] += 1
 
@@ -72,6 +73,7 @@ def benchmark2():
 
     for p in proxys:
         p.get_service().stop()
+    sleep(0.5)
 
 
 def main():
@@ -95,14 +97,17 @@ def main():
     rpc = get_rpc_by_addr(endpoint)
     rpc.stop()
 
-if __name__ == '__main__':
-    argv = sys.argv
-    if len(argv) == 1:
-        main()
-    elif argv[1] == 'b1':
-        benchmark()
-    elif argv[1] == 'b2':
-        benchmark2()
-
+#if __name__ == '__main__':
+#    argv = sys.argv
+#    if len(argv) == 1:
+#        main()
+#    elif argv[1] == 'b1':
+#        benchmark()
+#    elif argv[1] == 'b2':
+#        benchmark2()
+#else:
+#    print 'profile'
+#    benchmark2()
+benchmark2()
 
 
